##
##  python-time.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package versions
%define       V_python        3.11
%define       V_pytz          2024.1
%define       V_pyRFC3339     1.1
%define       V_parsedatetime 2.6
%define       V_dateutil      2.8.2

#   package information
Name:         python-time
Summary:      Python Modules for Time
URL:          http://www.python.org/
Vendor:       Python Community
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Language
License:      GPL
Version:      %{V_python}
Release:      20240204

#   list of sources
Source0:      https://files.pythonhosted.org/packages/source/p/pytz/pytz-%{V_pytz}.tar.gz
Source1:      https://files.pythonhosted.org/packages/source/p/pyRFC3339/pyRFC3339-%{V_pyRFC3339}.tar.gz
Source2:      https://files.pythonhosted.org/packages/source/p/parsedatetime/parsedatetime-%{V_parsedatetime}.tar.gz
Source3:      https://files.pythonhosted.org/packages/source/p/python-dateutil/python-dateutil-%{V_dateutil}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, python >= %{V_python}
PreReq:       OpenPKG, openpkg >= 20160101, python >= %{V_python}

%description
    This is a set of Python extension modules for time.

%track
    prog python-time:pytz = {
        version   = %{V_pytz}
        url       = https://pypi.python.org/pypi/pytz
        regex     = pytz-(__VER__)\.tar\.gz
    }
    prog python-time:pyRFC3339 = {
        version   = %{V_pyRFC3339}
        url       = https://pypi.python.org/pypi/pyRFC3339
        regex     = pyRFC3339-(__VER__)\.tar\.gz
    }
    prog python-time:parsedatetime = {
        version   = %{V_parsedatetime}
        url       = https://pypi.python.org/pypi/parsedatetime
        regex     = parsedatetime-(__VER__)\.tar\.gz
    }
    prog python-time:dateutil = {
        version   = %{V_dateutil}
        url       = https://pypi.python.org/pypi/python-dateutil
        regex     = python-dateutil-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1
    %setup -q -T -D -a 2
    %setup -q -T -D -a 3

%build

%install
    export PYTHONPATH=$RPM_BUILD_ROOT%{l_prefix}/lib/python%{V_python}/site-packages
    ( cd pytz-%{V_pytz}
      %{l_prefix}/bin/python \
          setup.py install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix}
    ) || exit $?
    ( cd pyRFC3339-%{V_pyRFC3339}
      %{l_prefix}/bin/python \
          setup.py install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix}
    ) || exit $?
    ( cd parsedatetime-%{V_parsedatetime}
      %{l_prefix}/bin/python \
          setup.py install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix}
    ) || exit $?
    ( cd python-dateutil-%{V_dateutil}
      %{l_prefix}/bin/python \
          setup.py install \
          --root=$RPM_BUILD_ROOT \
          --prefix=%{l_prefix}
    ) || exit $?
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

